var appInsights;
var sdk_version = 'unknown';
var logLevel = {"ALL":100,
                "CRITICAL":50,
                "ERROR":40,
                "WARNING":30,
                "INFO":20,
                "DEBUG":10};

Object.freeze(logLevel);

// log everything by default
var _level = logLevel.ALL;

// const instrumentationKey = '3221738b-6bce-4ac0-88fa-93728662a8de'; // test
const instrumentationKey = '38e39c8b-2fbb-4a95-aa50-0c66384962a7'; // prod

var _setCustomTelemetryProperty = function (telemetryName, telemetryValue){
    if(appInsights){            
        appInsights.queue.push(function(){
            appInsights.context.addTelemetryInitializer(function (envelope) {
                var telemetryItem = envelope.data.baseData;
    
                // set custom property:
                telemetryItem.properties = telemetryItem.properties || {};
                telemetryItem.properties[telemetryName] = telemetryValue;
            });
        });    
    }        
}
var _setCustomTelemetryMetric = function (telemetryName, telemetryValue){
    if(appInsights){            
        appInsights.queue.push(function (){
            appInsights.context.addTelemetryInitializer(function (envelope) {
                var telemetryItem = envelope.data.baseData;
    
                // set custom metric:
                telemetryItem.measurements = telemetryItem.measurements || {};
                telemetryItem.measurements[telemetryName] = telemetryValue;
            });
        });
    }        
}

// set minimum log level threshold 
var setLevel = function (level){
    if (typeof level === 'string'){        
        _level = logLevel[level] !== 'undefined' ? logLevel[level] : _level;
    } else{
        _level = level;
    }    
}

module.exports = {    
    init: function (send_telemetry, sdk_version, level){    
        if(level) 
        {
            setLevel(level);
        }

        if(send_telemetry)
        {
            sdk_version = String(sdk_version);            
            appInsights=window.appInsights||function(config){
                function s(config){t[config]=function(){var i=arguments;t.queue.push(function(){t[config].apply(t,i)})}}var t={config:config},r=document,f=window,e="script",o=r.createElement(e),i,u;for(o.src=config.url||"//az416426.vo.msecnd.net/scripts/a/ai.0.js",r.getElementsByTagName(e)[0].parentNode.appendChild(o),t.cookie=r.cookie,t.queue=[],i=["Event","Exception","Metric","PageView","Trace"];i.length;)s("track"+i.pop());return config.disableExceptionTracking||(i="onerror",s("_"+i),u=f[i],f[i]=function(config,r,f,e,o){var s=u&&u(config,r,f,e,o);return s!==!0&&t["_"+i](config,r,f,e,o),s}),t
            }({                
                instrumentationKey: instrumentationKey
            });
            window.appInsights=appInsights,appInsights.queue&&0===appInsights.queue.length&&appInsights.trackPageView();
        }

        return appInsights;
    },
    error: function (message, props){
        if (!appInsights)
        {
            return;
        }

        props.message = message;
        props.sdk_version = sdk_version;

        if (_level >= logLevel.ERROR){
            appInsights.trackEvent("Error", props);
        }
    },
    warning: function (message, props){
        if (!appInsights)
        {
            return;
        }
        
        props.message = message;
        props.sdk_version = sdk_version;

        if (_level >= logLevel.WARNING){
            appInsights.trackEvent("Warning", props);
        }
    },    
    info: function (message, props){
        if (!appInsights)        
        {            
            return;
        }

        props.message = message;
        props.sdk_version = sdk_version;
        
        if (_level >= logLevel.INFO){
            appInsights.trackEvent("Info", props);
        }
    },    
    debug: function (message, props){
        if (appInsights)
        {
            return;
        }

        props.message = message;
        props.sdk_version = sdk_version;
        
        if (_level >= logLevel.DEBUG){
            appInsights.trackEvent("Debug", props);
        }
    }   
}